- Added functions ``xoutil.objects.dict_merge``,
  ``xoutil.types.are_instances`` and ``xoutil.types.no_instances``.

- Deprecated function ``xoutil.objects.smart_getattr``.  Use
  ``xoutil.objects.get_first_of`` instead.
